@@ -21,7 +21,6 @@ import asyncio
 import base64
 import logging
 
-
 from typing import Any, AsyncGenerator, List, Optional, Tuple, Union
 
 from libsimba.schemas import (
@@ -35,9 +34,20 @@ from libsimba.schemas import (
     TxnHeaders,
 )
 from libsimba.simba_contract import SimbaContract
-from libsimba.simba_request import GetRequest, PatchRequest, PostRequest, PutRequest, SimbaRequest
+from libsimba.simba_request import (
+    GetRequest,
+    PatchRequest,
+    PostRequest,
+    PutRequest,
+    SimbaRequest,
+)
 from libsimba.simba_sync import SimbaSync
-from libsimba.utils import Path, get_address, get_deployed_artifact_id, get_address_by_name
+from libsimba.utils import (
+    Path,
+    get_address,
+    get_address_by_name,
+    get_deployed_artifact_id,
+)
 
 
 logger = logging.getLogger(__name__)
@@ -502,13 +512,15 @@ class Simba(SimbaSync):
         app_id: str,
         contract_name: str,
         method_name: str,
-        inputs: Optional[dict],
+        inputs: Optional[dict] = None,
+        headers: Optional[dict] = None,
         files: FileDict = None,
         txn_headers: TxnHeaders = None,
         login: Login = None,
         config: ConnectionConfig = None,
     ) -> dict:
-        headers = txn_headers.as_headers() if txn_headers else {}
+        headers = headers or {}
+        headers.update(txn_headers.as_headers() if txn_headers else {})
         inputs = inputs if inputs else {}
         result = await PostRequest(
             endpoint=Path.CONTRACT_METHOD.format(app_id, contract_name, method_name),
@@ -522,26 +534,29 @@ class Simba(SimbaSync):
         contract_name: str,
         method_name: str,
         args: Optional[MethodCallArgs] = None,
+        headers: Optional[dict] = None,
         login: Login = None,
         config: ConnectionConfig = None,
     ) -> dict:
         return await GetRequest(
             endpoint=Path.CONTRACT_METHOD.format(app_id, contract_name, method_name),
             login=login,
-        ).call(config=config, args=args)
+        ).call(config=config, args=args, headers=headers or {})
 
     async def submit_contract_method_sync(
         self,
         app_id: str,
         contract_name: str,
         method_name: str,
-        inputs: Optional[dict],
+        inputs: Optional[dict] = None,
+        headers: Optional[dict] = None,
         files: FileDict = None,
         txn_headers: TxnHeaders = None,
         login: Login = None,
         config: ConnectionConfig = None,
     ) -> dict:
-        headers = txn_headers.as_headers() if txn_headers else {}
+        headers = headers or {}
+        headers.update(txn_headers.as_headers() if txn_headers else {})
         inputs = inputs if inputs else {}
         result = await PostRequest(
             endpoint=Path.SYNC_CONTRACT_METHOD.format(
@@ -557,12 +572,13 @@ class Simba(SimbaSync):
         app_id: str,
         txn_id: str,
         txn: dict,
+        headers: Optional[dict] = None,
         login: Login = None,
         config: ConnectionConfig = None,
     ) -> dict:
         return await PatchRequest(
             endpoint=Path.APP_TXN.format(app_id, txn_id), login=login
-        ).patch(json_payload={"transaction": txn}, config=config)
+        ).patch(json_payload={"transaction": txn}, config=config, headers=headers or {})
 
     async def save_design(
         self,
@@ -574,6 +590,7 @@ class Simba(SimbaSync):
         libraries: dict = None,
         encode: bool = True,
         model: str = None,
+        extras: Optional[dict] = None,
         binary_targets: List[str] = None,
         login: Login = None,
         config: ConnectionConfig = None,
@@ -595,6 +612,8 @@ class Simba(SimbaSync):
             full["model"] = model
         if binary_targets is not None:
             full["binary_targets"] = binary_targets
+        if extras is not None:
+            full["extras"] = extras
         if not config:
             config = ConnectionConfig()
         if config.timeout < 120:
@@ -738,7 +757,7 @@ class Simba(SimbaSync):
             app_name=app_name,
             encode=encode,
             login=login,
-            config=config
+            config=config,
         )
         deployment_id = res["deployment_id"]
         try:
@@ -746,7 +765,11 @@ class Simba(SimbaSync):
             address = get_address_by_name(deployed, lib_name)
             library_id = get_deployed_artifact_id(deployed)
         except Exception as ex:
-            logger.warning("[wait_for_deploy_library] :: failed to wait for deployment: {}".format(ex))
+            logger.warning(
+                "[wait_for_deploy_library] :: failed to wait for deployment: {}".format(
+                    ex
+                )
+            )
             address = None
             library_id = None
         return address, library_id
@@ -775,7 +798,7 @@ class Simba(SimbaSync):
             args=args,
             display_name=display_name,
             login=login,
-            config=config
+            config=config,
         )
         deployment_id = res["deployment_id"]
         try:
@@ -812,7 +835,7 @@ class Simba(SimbaSync):
             args=args,
             display_name=display_name,
             login=login,
-            config=config
+            config=config,
         )
         deployment_id = res["id"]
         try:
@@ -907,6 +930,7 @@ class Simba(SimbaSync):
         nickname: Optional[str] = None,
         alias: Optional[str] = None,
         network: Optional[str] = None,
+        headers: Optional[dict] = None,
         login: Login = None,
         config: ConnectionConfig = None,
     ) -> List[dict]:
@@ -914,27 +938,34 @@ class Simba(SimbaSync):
         if nickname or alias:
             params = SearchFilter()
             if nickname:
-                params.add_filter(FieldFilter(field="nickname", op=FilterOp.EQ, value=nickname))
+                params.add_filter(
+                    FieldFilter(field="nickname", op=FilterOp.EQ, value=nickname)
+                )
             if alias:
-                params.add_filter(FieldFilter(field="alias", op=FilterOp.EQ, value=alias))
+                params.add_filter(
+                    FieldFilter(field="alias", op=FilterOp.EQ, value=alias)
+                )
             if network:
-                params.add_filter(FieldFilter(field="networks", op=FilterOp.EQ, value=network))
+                params.add_filter(
+                    FieldFilter(field="networks", op=FilterOp.EQ, value=network)
+                )
         return await SimbaRequest(
             endpoint=Path.USER_ACCOUNTS,
             query_params=params,
             login=login,
-        ).retrieve(config=config)
+        ).retrieve(config=config, headers=headers or {})
 
     async def get_account(
-            self,
-            uid: str,
-            login: Login = None,
-            config: ConnectionConfig = None,
+        self,
+        uid: str,
+        headers: Optional[dict] = None,
+        login: Login = None,
+        config: ConnectionConfig = None,
     ) -> dict:
         return await SimbaRequest(
             endpoint=Path.USER_ACCOUNT.format(uid),
             login=login,
-        ).send(config=config)
+        ).send(config=config, headers=headers or {})
 
     async def create_account(
         self,
@@ -943,21 +974,22 @@ class Simba(SimbaSync):
         nickname: str,
         alias: str,
         network_type: Optional[str] = "ethereum",
+        headers: Optional[dict] = None,
         login: Login = None,
         config: ConnectionConfig = None,
     ) -> dict:
         payload = {
-          "network_type": network_type,
-          "network_subtype": network_subtype,
-          "network": network,
-          "nickname": nickname,
-          "alias": alias
+            "network_type": network_type,
+            "network_subtype": network_subtype,
+            "network": network,
+            "nickname": nickname,
+            "alias": alias,
         }
         return await SimbaRequest(
             method="POST",
             endpoint=Path.USER_ACCOUNTS,
             login=login,
-        ).send(config=config, json_payload=payload)
+        ).send(config=config, json_payload=payload, headers=headers or {})
 
     async def set_account(
         self,
@@ -968,35 +1000,37 @@ class Simba(SimbaSync):
         address: str,
         private_key: str,
         network_type: Optional[str] = "ethereum",
+        headers: Optional[dict] = None,
         login: Login = None,
         config: ConnectionConfig = None,
     ) -> dict:
         payload = {
-          "network_type": network_type,
-          "network_subtype": network_subtype,
-          "network": network,
-          "nickname": nickname,
-          "alias": alias,
-          "public_key": address,
-          "private_key": private_key
+            "network_type": network_type,
+            "network_subtype": network_subtype,
+            "network": network,
+            "nickname": nickname,
+            "alias": alias,
+            "public_key": address,
+            "private_key": private_key,
         }
         return await SimbaRequest(
             method="POST",
             endpoint=Path.USER_ACCOUNT_SET,
             login=login,
-        ).send(config=config, json_payload=payload)
+        ).send(config=config, json_payload=payload, headers=headers or {})
 
     async def account_sign(
         self,
         uid: str,
         input_pairs: List[Tuple[str, Any]],
         hash_message: Optional[bool] = False,
+        headers: Optional[dict] = None,
         login: Login = None,
         config: ConnectionConfig = None,
     ) -> dict:
         payload = {
             "input_pairs": [list(t) for t in input_pairs],
-            "hash_message": hash_message
+            "hash_message": hash_message,
         }
         return await SimbaRequest(
             method="POST",
@@ -1004,6 +1038,218 @@ class Simba(SimbaSync):
             login=login,
         ).send(config=config, json_payload=payload)
 
+    async def account_address_sign(
+        self,
+        blockchain: str,
+        address: str,
+        input_pairs: List[Tuple[str, Any]],
+        hash_message: Optional[bool] = False,
+        headers: Optional[dict] = None,
+        login: Login = None,
+        config: ConnectionConfig = None,
+    ) -> dict:
+        payload = {
+            "input_pairs": [list(t) for t in input_pairs],
+            "hash_message": hash_message,
+        }
+        return await SimbaRequest(
+            method="POST",
+            endpoint=Path.USER_ACCOUNT_ADDRESS_SIGN.create(blockchain, address),
+            login=login,
+        ).send(config=config, json_payload=payload)
+
+    async def admin_get_accounts(
+        self,
+        alias: Optional[str] = None,
+        network: Optional[str] = None,
+        owner_type: Optional[str] = None,
+        owner_identifier: Optional[str] = None,
+        headers: Optional[dict] = None,
+        login: Login = None,
+        config: ConnectionConfig = None,
+    ) -> List[dict]:
+        """
+        GET ``/v2/organisations/{org}/accounts/``
+
+        Get the accounts for the current user. Optionally filter on
+        nickname or alias.
+
+        :Keyword Arguments:
+            * **nickname** (`Optional[str]`)
+            * **alias** (`Optional[str]`)
+            * **network** (`Optional[str]`)
+            * **owner_identifier** (`Optional[str]`)
+            * **owner_type** (`Optional[str]`)
+            * **headers** (`Optional[dict]`) additional http headers
+            * **login** (`Optional[Login]`)
+            * **config** (`Optional[ConnectionConfig]`)
+        :return: a list of account objects
+        :rtype: list
+        """
+        params = None
+        if alias or network or owner_type:
+            params = SearchFilter()
+            if owner_type:
+                params.add_filter(
+                    FieldFilter(field="owner_type", op=FilterOp.EQ, value=owner_type)
+                )
+                if owner_identifier:
+                    params.add_filter(
+                        FieldFilter(field="owner_identifier", op=FilterOp.EQ, value=owner_identifier)
+                    )
+            if alias:
+                params.add_filter(
+                    FieldFilter(field="alias", op=FilterOp.EQ, value=alias)
+                )
+            if network:
+                params.add_filter(
+                    FieldFilter(field="networks", op=FilterOp.EQ, value=network)
+                )
+        return await SimbaRequest(
+            endpoint=Path.ADMIN_ACCOUNTS,
+            query_params=params,
+            login=login,
+        ).retrieve(config=config, headers=headers or {})
+
+    async def get_org_accounts(
+        self,
+        org: str,
+        nickname: Optional[str] = None,
+        alias: Optional[str] = None,
+        network: Optional[str] = None,
+        headers: Optional[dict] = None,
+        login: Login = None,
+        config: ConnectionConfig = None,
+    ) -> List[dict]:
+        params = None
+        if nickname or alias:
+            params = SearchFilter()
+            if nickname:
+                params.add_filter(
+                    FieldFilter(field="nickname", op=FilterOp.EQ, value=nickname)
+                )
+            if alias:
+                params.add_filter(
+                    FieldFilter(field="alias", op=FilterOp.EQ, value=alias)
+                )
+            if network:
+                params.add_filter(
+                    FieldFilter(field="networks", op=FilterOp.EQ, value=network)
+                )
+        return await SimbaRequest(
+            endpoint=Path.ORG_ACCOUNTS.create(org),
+            query_params=params,
+            login=login,
+        ).retrieve(config=config, headers=headers or {})
+
+    async def get_org_account(
+        self,
+        org: str,
+        uid: str,
+        headers: Optional[dict] = None,
+        login: Login = None,
+        config: ConnectionConfig = None,
+    ) -> dict:
+        return await SimbaRequest(
+            endpoint=Path.ORG_ACCOUNT.create(org, uid),
+            login=login,
+        ).send(config=config, headers=headers or {})
+
+    async def create_org_account(
+        self,
+        org: str,
+        network_subtype: str,
+        network: str,
+        nickname: str,
+        alias: str,
+        network_type: Optional[str] = "ethereum",
+        headers: Optional[dict] = None,
+        login: Login = None,
+        config: ConnectionConfig = None,
+    ) -> dict:
+        payload = {
+            "network_type": network_type,
+            "network_subtype": network_subtype,
+            "network": network,
+            "nickname": nickname,
+            "alias": alias,
+        }
+        return await SimbaRequest(
+            method="POST",
+            endpoint=Path.ORG_ACCOUNTS.create(org),
+            login=login,
+        ).send(config=config, json_payload=payload, headers=headers or {})
+
+    async def set_org_account(
+        self,
+        org: str,
+        network_subtype: str,
+        network: str,
+        nickname: str,
+        alias: str,
+        address: str,
+        private_key: str,
+        network_type: Optional[str] = "ethereum",
+        headers: Optional[dict] = None,
+        login: Login = None,
+        config: ConnectionConfig = None,
+    ) -> dict:
+        payload = {
+            "network_type": network_type,
+            "network_subtype": network_subtype,
+            "network": network,
+            "nickname": nickname,
+            "alias": alias,
+            "public_key": address,
+            "private_key": private_key,
+        }
+        return await SimbaRequest(
+            method="POST",
+            endpoint=Path.ORG_ACCOUNT_SET.create(org),
+            login=login,
+        ).send(config=config, json_payload=payload, headers=headers or {})
+
+    async def org_account_sign(
+        self,
+        org: str,
+        uid: str,
+        input_pairs: List[Tuple[str, Any]],
+        hash_message: Optional[bool] = False,
+        headers: Optional[dict] = None,
+        login: Login = None,
+        config: ConnectionConfig = None,
+    ) -> dict:
+        payload = {
+            "input_pairs": [list(t) for t in input_pairs],
+            "hash_message": hash_message,
+        }
+        return await SimbaRequest(
+            method="POST",
+            endpoint=Path.ORG_ACCOUNT_SIGN.create(org, uid),
+            login=login,
+        ).send(config=config, json_payload=payload)
+
+    async def org_account_address_sign(
+        self,
+        org: str,
+        blockchain: str,
+        address: str,
+        input_pairs: List[Tuple[str, Any]],
+        hash_message: Optional[bool] = False,
+        headers: Optional[dict] = None,
+        login: Login = None,
+        config: ConnectionConfig = None,
+    ) -> dict:
+        payload = {
+            "input_pairs": [list(t) for t in input_pairs],
+            "hash_message": hash_message,
+        }
+        return await SimbaRequest(
+            method="POST",
+            endpoint=Path.ORG_ACCOUNT_ADDRESS_SIGN.create(org, blockchain, address),
+            login=login,
+        ).send(config=config, json_payload=payload)
+
     async def get_artifacts(
         self,
         org: str,
@@ -1011,7 +1257,7 @@ class Simba(SimbaSync):
         config: ConnectionConfig = None,
     ) -> List[dict]:
         return await SimbaRequest(
-            endpoint=Path.CONTRACT_ARTIFACTS.format(org),
+            endpoint=Path.CONTRACT_ARTIFACTS.create(org),
             login=login,
         ).retrieve(config=config)
 
