@@ -21,7 +21,7 @@
 import json
 import logging
 
-from typing import AsyncGenerator, Generator, List, Optional, Union
+from typing import Any, AsyncGenerator, Dict, Generator, List, Optional, Tuple, Union
 
 import httpx
 
@@ -48,6 +48,30 @@ PROVIDERS = {"client_credentials": ClientCredentials()}
 logger = logging.getLogger(__name__)
 
 
+class Pager:
+
+    def list(self, page: Dict[str, Any]) -> List[Any]:
+        if page.get("results"):
+            return page["results"]
+        elif page.get("items"):
+            return page["items"]
+        return []
+
+    def next(
+        self, url: str, page: Dict[str, Any], params: Dict[str, Any]
+    ) -> Tuple[Optional[str], Optional[Dict[str, Any]]]:
+        if page.get("results"):
+            return page.get("next"), None
+        elif page.get("items"):
+            curr_page = int(page.get("page", "1"))
+            total_pages = int(page.get("pages", "1"))
+            if curr_page < total_pages:
+                params["page"] = curr_page + 1
+                params["size"] = int(page.get("size", "50"))
+                return url, params
+        return None, None
+
+
 class SimbaRequest(object):
     def __init__(
         self,
@@ -55,6 +79,8 @@ class SimbaRequest(object):
         method: str = "GET",
         query_params: Union[dict, SearchFilter] = None,
         login: Login = None,
+        base_url: Optional[str] = None,
+        authenticated: bool = True,
     ):
         """
         Create a SimbaRequest
@@ -75,6 +101,8 @@ class SimbaRequest(object):
             query_params = query_params.filter_query
         self.query_params = query_params
         self.curr_login = login or self.default_login
+        self.base_url = base_url
+        self.authenticated = authenticated
         self.method = method.upper()
         self._status = -1
         self._response = None
@@ -121,7 +149,10 @@ class SimbaRequest(object):
         :return: the URL
         :rtype: str
         """
-        return build_url(settings().API_BASE_URL, self.endpoint, self.query_params)
+        if self.base_url:
+            return build_url(self.base_url, self.endpoint, self.query_params)
+        else:
+            return build_url(settings().API_BASE_URL, self.endpoint, self.query_params)
 
     @property
     def response(self) -> httpx.Response:
@@ -155,7 +186,10 @@ class SimbaRequest(object):
 
     @staticmethod
     def login(
-        login: Login, headers: Optional[dict] = None, config: ConnectionConfig = None
+        login: Login,
+        headers: Optional[dict] = None,
+        config: ConnectionConfig = None,
+        authenticated: bool = True,
     ) -> dict:
         """
         Login. If an Authorization header is found in the headers,
@@ -171,18 +205,22 @@ class SimbaRequest(object):
         :rtype: dict
         """
         headers = headers or {}
-        if headers.get("Authorization") is None:
-            auth_token = PROVIDERS[login.auth_flow].login_sync(
-                client_id=login.client_id,
-                client_secret=login.client_secret,
-                config=config,
-            )
-            headers["Authorization"] = f"Bearer {auth_token.token}"
+        if not authenticated:
+            return headers
+        _ = PROVIDERS[login.auth_flow].login_sync(
+            client_id=login.client_id,
+            client_secret=login.client_secret,
+            headers=headers,
+            config=config,
+        )
         return headers
 
     @staticmethod
     async def async_login(
-        login: Login, headers: Optional[dict] = None, config: ConnectionConfig = None
+        login: Login,
+        headers: Optional[dict] = None,
+        config: ConnectionConfig = None,
+        authenticated: bool = True,
     ) -> dict:
         """
         Async login. If an Authorization header is found in the headers,
@@ -199,13 +237,14 @@ class SimbaRequest(object):
         :rtype: dict
         """
         headers = headers or {}
-        if headers.get("Authorization") is None:
-            auth_token = await PROVIDERS[login.auth_flow].login(
-                client_id=login.client_id,
-                client_secret=login.client_secret,
-                config=config,
-            )
-            headers["Authorization"] = f"Bearer {auth_token.token}"
+        if not authenticated:
+            return headers
+        _ = await PROVIDERS[login.auth_flow].login(
+            client_id=login.client_id,
+            client_secret=login.client_secret,
+            headers=headers,
+            config=config,
+        )
         return headers
 
     async def download(
@@ -225,7 +264,9 @@ class SimbaRequest(object):
             * **config** (`Optional[ConnectionConfig]`)
         :return: None
         """
-        headers = await SimbaRequest.async_login(self.curr_login, headers)
+        headers = await SimbaRequest.async_login(
+            self.curr_login, headers, config, self.authenticated
+        )
         logger.debug(self.log_me(headers=headers, current_method="download"))
         with open(location, "wb") as output:
             async with async_http_client(config=config) as async_client:
@@ -252,7 +293,9 @@ class SimbaRequest(object):
             * **config** (`Optional[ConnectionConfig]`)
         :return: None
         """
-        headers = SimbaRequest.login(self.curr_login, headers, config=config)
+        headers = SimbaRequest.login(
+            self.curr_login, headers, config=config, authenticated=self.authenticated
+        )
         logger.debug(self.log_me(headers=headers, current_method="download_sync"))
         with open(location, "wb") as output:
             with http_client(config=config) as client:
@@ -278,8 +321,17 @@ class SimbaRequest(object):
         :return: return value dictionary containing, return value, request ID and status
         :rtype: dict
         """
-        headers = SimbaRequest.login(self.curr_login, headers, config=config)
-        params = args.args if args else None
+        headers = SimbaRequest.login(
+            self.curr_login, headers, config=config, authenticated=self.authenticated
+        )
+        params = None
+        if args and args.args:
+            params = {}
+            for k, p in args.args.items():
+                if isinstance(p, (dict, list)):
+                    params[k] = json.dumps(p, separators=(",", ":"))
+                else:
+                    params[k] = p
         logger.debug(
             self.log_me(headers=headers, params=params, current_method="call_sync")
         )
@@ -306,9 +358,16 @@ class SimbaRequest(object):
         :rtype: dict
         """
         headers = await SimbaRequest.async_login(
-            self.curr_login, headers, config=config
+            self.curr_login, headers, config=config, authenticated=self.authenticated
         )
-        params = args.args if args else None
+        params = None
+        if args and args.args:
+            params = {}
+            for k, p in args.args.items():
+                if isinstance(p, (dict, list)):
+                    params[k] = json.dumps(p, separators=(",", ":"))
+                else:
+                    params[k] = p
         logger.debug(self.log_me(headers=headers, params=params, current_method="call"))
         async with async_http_client(config=config) as async_client:
             response = await async_client.get(
@@ -334,7 +393,9 @@ class SimbaRequest(object):
         :return: A dictionary response object
         :rtype: dict
         """
-        headers = SimbaRequest.login(self.curr_login, headers, config=config)
+        headers = SimbaRequest.login(
+            self.curr_login, headers, config=config, authenticated=self.authenticated
+        )
         logger.debug(self.log_me(headers=headers, current_method="send_sync"))
         with http_client(config=config) as client:
             if self.method == "GET":
@@ -381,7 +442,7 @@ class SimbaRequest(object):
         config: ConnectionConfig = None,
     ) -> Generator[List[dict], None, None]:
         """
-        Get multiple results as a generator. This will loop through paging if the result is pageed.
+        Get multiple results as a generator. This will loop through paging if the result is paged.
 
         :Keyword Arguments:
             * **headers** (`Optional[dict]`) - optional headers
@@ -389,18 +450,26 @@ class SimbaRequest(object):
         :return: A generator of lists of dicts
         :rtype: Generator[List[dict], None, None]
         """
-        headers = SimbaRequest.login(self.curr_login, headers, config=config)
+        headers = SimbaRequest.login(
+            self.curr_login, headers, config=config, authenticated=self.authenticated
+        )
         logger.debug(self.log_me(headers=headers, current_method="retrieve_iter_sync"))
         with http_client(config=config) as client:
+            pager = Pager()
             next_page_url = self.url
+            params = self.query_params
             while next_page_url is not None:
-                r = client.get(next_page_url, headers=headers, follow_redirects=True)
+                r = client.get(
+                    next_page_url, headers=headers, follow_redirects=True, params=params
+                )
                 self._json_response = self._json_response_or_raise(r)
-                results = self._json_response.get("results")
+                results = pager.list(self._json_response)
                 if not results:
                     yield None
                     return
-                next_page_url = self._json_response.get("next")
+                next_page_url, params = pager.next(
+                    url=next_page_url, page=self._json_response, params=params
+                )
                 yield results
 
     def retrieve_sync(
@@ -417,12 +486,15 @@ class SimbaRequest(object):
         :return: A list of objects
         :rtype: List[dict]
         """
-        headers = SimbaRequest.login(self.curr_login, headers, config=config)
+        headers = SimbaRequest.login(
+            self.curr_login, headers, config=config, authenticated=self.authenticated
+        )
         logger.debug(self.log_me(headers=headers, current_method="retrieve_sync"))
         with http_client(config=config) as client:
+            pager = Pager()
             r = client.get(self.url, headers=headers, follow_redirects=True)
             self._json_response = self._json_response_or_raise(r)
-            results = self.json_response.get("results")
+            results = pager.list(self.json_response)
         return results
 
     async def retrieve_iter(
@@ -440,21 +512,25 @@ class SimbaRequest(object):
         :rtype: AsyncGenerator[List[dict], None]
         """
         headers = await SimbaRequest.async_login(
-            self.curr_login, headers, config=config
+            self.curr_login, headers, config=config, authenticated=self.authenticated
         )
         logger.debug(self.log_me(headers=headers, current_method="retrieve_iter"))
         async with async_http_client(config=config) as async_client:
+            pager = Pager()
             next_page_url = self.url
+            params = self.query_params
             while next_page_url is not None:
                 r = await async_client.get(
-                    next_page_url, headers=headers, follow_redirects=True
+                    next_page_url, headers=headers, follow_redirects=True, params=params
                 )
                 self._json_response = self._json_response_or_raise(r)
-                results = self._json_response.get("results")
+                results = pager.list(self._json_response)
                 if not results:
                     yield None
                     break
-                next_page_url = self._json_response.get("next")
+                next_page_url, params = pager.next(
+                    url=next_page_url, page=self._json_response, params=params
+                )
                 yield results
 
     async def retrieve(
@@ -472,13 +548,14 @@ class SimbaRequest(object):
         :rtype: List[dict]
         """
         headers = await SimbaRequest.async_login(
-            self.curr_login, headers, config=config
+            self.curr_login, headers, config=config, authenticated=self.authenticated
         )
         logger.debug(self.log_me(headers=headers, current_method="retrieve"))
         async with async_http_client(config=config) as async_client:
+            pager = Pager()
             r = await async_client.get(self.url, headers=headers, follow_redirects=True)
             self._json_response = self._json_response_or_raise(r)
-            results = self.json_response.get("results")
+            results = pager.list(self.json_response)
         return results
 
     async def send(
@@ -500,7 +577,7 @@ class SimbaRequest(object):
         :rtype: dict
         """
         headers = await SimbaRequest.async_login(
-            self.curr_login, headers, config=config
+            self.curr_login, headers, config=config, authenticated=self.authenticated
         )
         logger.debug(self.log_me(headers=headers, current_method="send"))
         async with async_http_client(config=config) as async_client:
@@ -564,7 +641,7 @@ class SimbaRequest(object):
             response.raise_for_status()
         except (InvalidURL, ConnectError, ProtocolError, ValueError) as e:
             raise SimbaInvalidURLException(str(e))
-        except (RequestError) as e:
+        except RequestError as e:
             raise SimbaRequestException(f"{e} :: {self._response.text}")
         except Exception as e:
             raise LibSimbaException(message=f"{e} :: {self._response.text}")
@@ -577,9 +654,16 @@ class GetRequest(SimbaRequest):
         endpoint: str,
         query_params: Union[dict, SearchFilter] = None,
         login: Login = None,
+        base_url: Optional[str] = None,
+        authenticated: bool = True,
     ):
         super().__init__(
-            endpoint=endpoint, method="GET", query_params=query_params, login=login
+            endpoint=endpoint,
+            method="GET",
+            query_params=query_params,
+            login=login,
+            base_url=base_url,
+            authenticated=authenticated,
         )
 
     def get_sync(
@@ -620,8 +704,16 @@ class PostRequest(SimbaRequest):
         self,
         endpoint: str,
         login: Login = None,
+        base_url: Optional[str] = None,
+        authenticated: bool = True,
     ):
-        super().__init__(endpoint=endpoint, method="POST", login=login)
+        super().__init__(
+            endpoint=endpoint,
+            method="POST",
+            login=login,
+            base_url=base_url,
+            authenticated=authenticated,
+        )
 
     def post_sync(
         self,
@@ -673,8 +765,16 @@ class PutRequest(SimbaRequest):
         self,
         endpoint: str,
         login: Login = None,
+        base_url: Optional[str] = None,
+        authenticated: bool = True,
     ):
-        super().__init__(endpoint=endpoint, method="PUT", login=login)
+        super().__init__(
+            endpoint=endpoint,
+            method="PUT",
+            login=login,
+            base_url=base_url,
+            authenticated=authenticated,
+        )
 
     def put_sync(
         self,
@@ -726,8 +826,16 @@ class PatchRequest(SimbaRequest):
         self,
         endpoint: str,
         login: Login = None,
+        base_url: Optional[str] = None,
+        authenticated: bool = True,
     ):
-        super().__init__(endpoint=endpoint, method="PATCH", login=login)
+        super().__init__(
+            endpoint=endpoint,
+            method="PATCH",
+            login=login,
+            base_url=base_url,
+            authenticated=authenticated,
+        )
 
     def patch_sync(
         self,
@@ -779,8 +887,16 @@ class DeleteRequest(SimbaRequest):
         self,
         endpoint: str,
         login: Login = None,
+        base_url: Optional[str] = None,
+        authenticated: bool = True,
     ):
-        super().__init__(endpoint=endpoint, method="DELETE", login=login)
+        super().__init__(
+            endpoint=endpoint,
+            method="DELETE",
+            login=login,
+            base_url=base_url,
+            authenticated=authenticated,
+        )
 
     def delete_sync(
         self,
