@@ -28,16 +28,27 @@ from libsimba.config import settings
 from libsimba.schemas import (
     ConnectionConfig,
     FieldFilter,
-    FilterOp,
     FileDict,
+    FilterOp,
     Login,
     MethodCallArgs,
     SearchFilter,
     TxnHeaders,
 )
 from libsimba.simba_contract_sync import SimbaContractSync
-from libsimba.simba_request import GetRequest, PatchRequest, PostRequest, PutRequest, SimbaRequest
-from libsimba.utils import Path, get_address, get_deployed_artifact_id, get_address_by_name
+from libsimba.simba_request import (
+    GetRequest,
+    PatchRequest,
+    PostRequest,
+    PutRequest,
+    SimbaRequest,
+)
+from libsimba.utils import (
+    Path,
+    get_address,
+    get_address_by_name,
+    get_deployed_artifact_id,
+)
 
 
 logger = logging.getLogger(__name__)
@@ -1120,7 +1131,8 @@ class SimbaSync:
         app_id: str,
         contract_name: str,
         method_name: str,
-        inputs: Optional[dict],
+        inputs: Optional[dict] = None,
+        headers: Optional[dict] = None,
         files: Optional[FileDict] = None,
         txn_headers: TxnHeaders = None,
         login: Login = None,
@@ -1141,6 +1153,7 @@ class SimbaSync:
 
         :Keyword Arguments:
             * **inputs** (`Optional[dict]`) - method parameters as a dictionary
+            * **headers** (`Optional[dict]`) - additional http headers
             * **files** (`Optional[FileDict]`) - optional off chain files to upload
             * **txn_headers** (`Optional[TxnHeaders]`) - optional transaction related headers to include
             * **login** (`Optional[Login]`)
@@ -1148,7 +1161,8 @@ class SimbaSync:
         :return: The transaction
         :rtype: dict
         """
-        headers = txn_headers.as_headers() if txn_headers else {}
+        headers = headers or {}
+        headers.update(txn_headers.as_headers() if txn_headers else {})
         inputs = inputs if inputs else {}
         result = PostRequest(
             endpoint=Path.CONTRACT_METHOD.format(app_id, contract_name, method_name),
@@ -1162,6 +1176,7 @@ class SimbaSync:
         contract_name: str,
         method_name: str,
         args: Optional[MethodCallArgs] = None,
+        headers: Optional[dict] = None,
         login: Login = None,
         config: ConnectionConfig = None,
     ) -> dict:
@@ -1179,23 +1194,25 @@ class SimbaSync:
 
         :Keyword Arguments:
             * **args** (`Optional[MethodCallArgs]`) - optional method parameters as a dict
-            * **txn_headers** (`Optional[TxnHeaders]`) - optional transaction related headers to include
+            * **headers** (`Optional[dict]`) - additional http headers
             * **login** (`Optional[Login]`)
             * **config** (`Optional[ConnectionConfig]`)
         :return: The getter response. The `value` field contains the result.
         :rtype: dict
         """
+        headers = headers or {}
         return GetRequest(
             endpoint=Path.CONTRACT_METHOD.format(app_id, contract_name, method_name),
             login=login,
-        ).call_sync(config=config, args=args)
+        ).call_sync(config=config, args=args, headers=headers)
 
     def submit_contract_method_sync(
         self,
         app_id: str,
         contract_name: str,
         method_name: str,
-        inputs: Optional[dict],
+        inputs: Optional[dict] = None,
+        headers: Optional[dict] = None,
         files: FileDict = None,
         txn_headers: TxnHeaders = None,
         login: Login = None,
@@ -1216,6 +1233,7 @@ class SimbaSync:
 
         :Keyword Arguments:
             * **inputs** (`Optional[dict]`) - method parameters as a dictionary
+            * **headers** (`Optional[dict]`) - additional http headers
             * **files** (`Optional[FileDict]`) - optional off chain files to upload
             * **txn_headers** (`Optional[TxnHeaders]`) - optional transaction related headers to include
             * **login** (`Optional[Login]`)
@@ -1223,7 +1241,8 @@ class SimbaSync:
         :return: The transaction
         :rtype: dict
         """
-        headers = txn_headers.as_headers() if txn_headers else {}
+        headers = headers or {}
+        headers.update(txn_headers.as_headers() if txn_headers else {})
         inputs = inputs if inputs else {}
         result = PostRequest(
             endpoint=Path.SYNC_CONTRACT_METHOD.format(
@@ -1239,6 +1258,7 @@ class SimbaSync:
         app_id: str,
         txn_id: str,
         txn: dict,
+        headers: Optional[dict] = None,
         login: Login = None,
         config: ConnectionConfig = None,
     ):
@@ -1260,9 +1280,10 @@ class SimbaSync:
         :return: The transaction
         :rtype: dict
         """
+        headers = headers or {}
         return PatchRequest(
             endpoint=Path.APP_TXN.format(app_id, txn_id), login=login
-        ).patch_sync(json_payload={"transaction": txn}, config=config)
+        ).patch_sync(json_payload={"transaction": txn}, config=config, headers=headers)
 
     def save_design(
         self,
@@ -1274,6 +1295,7 @@ class SimbaSync:
         libraries: dict = None,
         encode: bool = True,
         model: str = None,
+        extras: Optional[dict] = None,
         binary_targets: List[str] = None,
         login: Login = None,
         config: ConnectionConfig = None,
@@ -1282,7 +1304,7 @@ class SimbaSync:
         POST/PUT ``/v2/organisations/{organisation}/contract_designs/``
 
         Save a contract design, aka the code. If the design ID is given, this results in an update via a PUT.
-        Otherwise a new design is created via a POST.
+        Otherwise, a new design is created via a POST.
 
         :param org: The organisation to save to.
         :type org: str
@@ -1320,6 +1342,8 @@ class SimbaSync:
             full["model"] = model
         if binary_targets is not None:
             full["binary_targets"] = binary_targets
+        if extras is not None:
+            full["extras"] = extras
         if not config:
             config = ConnectionConfig()
         if config.timeout < 120:  # while this is sync, we need to be patient
@@ -1584,7 +1608,7 @@ class SimbaSync:
             app_name=app_name,
             encode=encode,
             login=login,
-            config=config
+            config=config,
         )
         deployment_id = res["deployment_id"]
         try:
@@ -1592,7 +1616,11 @@ class SimbaSync:
             address = get_address_by_name(deployed, lib_name)
             library_id = get_deployed_artifact_id(deployed)
         except Exception as ex:
-            logger.warning("[wait_for_deploy_library] :: failed to wait for deployment: {}".format(ex))
+            logger.warning(
+                "[wait_for_deploy_library] :: failed to wait for deployment: {}".format(
+                    ex
+                )
+            )
             address = None
             library_id = None
         return address, library_id
@@ -1646,7 +1674,7 @@ class SimbaSync:
             args=args,
             display_name=display_name,
             login=login,
-            config=config
+            config=config,
         )
         deployment_id = res["deployment_id"]
         try:
@@ -1708,7 +1736,7 @@ class SimbaSync:
             args=args,
             display_name=display_name,
             login=login,
-            config=config
+            config=config,
         )
         deployment_id = res["id"]
         try:
@@ -1911,6 +1939,7 @@ class SimbaSync:
         nickname: Optional[str] = None,
         alias: Optional[str] = None,
         network: Optional[str] = None,
+        headers: Optional[dict] = None,
         login: Login = None,
         config: ConnectionConfig = None,
     ) -> List[dict]:
@@ -1923,29 +1952,38 @@ class SimbaSync:
         :Keyword Arguments:
             * **nickname** (`Optional[str]`)
             * **alias** (`Optional[str]`)
+            * **network** (`Optional[str]`)
+            * **headers** (`Optional[dict]`) additional http headers
             * **login** (`Optional[Login]`)
             * **config** (`Optional[ConnectionConfig]`)
         :return: a list of account objects
         :rtype: list
         """
         params = None
-        if nickname or alias:
+        if nickname or alias or network:
             params = SearchFilter()
             if nickname:
-                params.add_filter(FieldFilter(field="nickname", op=FilterOp.EQ, value=nickname))
+                params.add_filter(
+                    FieldFilter(field="nickname", op=FilterOp.EQ, value=nickname)
+                )
             if alias:
-                params.add_filter(FieldFilter(field="alias", op=FilterOp.EQ, value=alias))
+                params.add_filter(
+                    FieldFilter(field="alias", op=FilterOp.EQ, value=alias)
+                )
             if network:
-                params.add_filter(FieldFilter(field="networks", op=FilterOp.EQ, value=network))
+                params.add_filter(
+                    FieldFilter(field="networks", op=FilterOp.EQ, value=network)
+                )
         return SimbaRequest(
             endpoint=Path.USER_ACCOUNTS,
             query_params=params,
             login=login,
-        ).retrieve_sync(config=config)
+        ).retrieve_sync(config=config, headers=headers or {})
 
     def get_account(
         self,
         uid: str,
+        headers: Optional[dict] = None,
         login: Login = None,
         config: ConnectionConfig = None,
     ) -> dict:
@@ -1955,6 +1993,7 @@ class SimbaSync:
         Get the account for the current user with the given id.
 
         :Keyword Arguments:
+            * **headers** (`Optional[dict]`) - additional http headers
             * **login** (`Optional[Login]`)
             * **config** (`Optional[ConnectionConfig]`)
         :return: an account object.
@@ -1963,7 +2002,7 @@ class SimbaSync:
         return SimbaRequest(
             endpoint=Path.USER_ACCOUNT.format(uid),
             login=login,
-        ).send_sync(config=config)
+        ).send_sync(config=config, headers=headers or {})
 
     def create_account(
         self,
@@ -1972,6 +2011,7 @@ class SimbaSync:
         nickname: str,
         alias: str,
         network_type: Optional[str] = "ethereum",
+        headers: Optional[dict] = None,
         login: Login = None,
         config: ConnectionConfig = None,
     ) -> dict:
@@ -1990,23 +2030,24 @@ class SimbaSync:
         :type alias: str
 
         :Keyword Arguments:
+            * **headers** (`Optional[dict]`) - additional http headers
             * **login** (`Optional[Login]`)
             * **config** (`Optional[ConnectionConfig]`)
         :return: an account object.
         :rtype: dict
         """
         payload = {
-          "network_type": network_type,
-          "network_subtype": network_subtype,
-          "network": network,
-          "nickname": nickname,
-          "alias": alias
+            "network_type": network_type,
+            "network_subtype": network_subtype,
+            "network": network,
+            "nickname": nickname,
+            "alias": alias,
         }
         return SimbaRequest(
             method="POST",
             endpoint=Path.USER_ACCOUNTS,
             login=login,
-        ).send_sync(config=config, json_payload=payload)
+        ).send_sync(config=config, json_payload=payload, headers=headers or {})
 
     def set_account(
         self,
@@ -2017,6 +2058,7 @@ class SimbaSync:
         address: str,
         private_key: str,
         network_type: Optional[str] = "ethereum",
+        headers: Optional[dict] = None,
         login: Login = None,
         config: ConnectionConfig = None,
     ) -> dict:
@@ -2040,31 +2082,33 @@ class SimbaSync:
 
         :Keyword Arguments:
             * **network_type** (`Optional[str]`)
+            * **headers** (`Optional[dict]`) - additional http headers
             * **login** (`Optional[Login]`)
             * **config** (`Optional[ConnectionConfig]`)
         :return: an account object.
         :rtype: dict
         """
         payload = {
-          "network_type": network_type,
-          "network_subtype": network_subtype,
-          "network": network,
-          "nickname": nickname,
-          "alias": alias,
-          "public_key": address,
-          "private_key": private_key
+            "network_type": network_type,
+            "network_subtype": network_subtype,
+            "network": network,
+            "nickname": nickname,
+            "alias": alias,
+            "public_key": address,
+            "private_key": private_key,
         }
         return SimbaRequest(
             method="POST",
             endpoint=Path.USER_ACCOUNT_SET,
             login=login,
-        ).send_sync(config=config, json_payload=payload)
+        ).send_sync(config=config, json_payload=payload, headers=headers or {})
 
     def account_sign(
         self,
         uid: str,
         input_pairs: List[Tuple[str, Any]],
         hash_message: Optional[bool] = False,
+        headers: Optional[dict] = None,
         login: Login = None,
         config: ConnectionConfig = None,
     ) -> dict:
@@ -2079,6 +2123,7 @@ class SimbaSync:
         :type input_pairs: List[Tuple(str, Any)]
 
         :Keyword Arguments:
+            * **headers** (`Optional[dict]`) - additional http headers
             * **login** (`Optional[Login]`)
             * **config** (`Optional[ConnectionConfig]`)
         :return: a Dict with the signed content.
@@ -2086,13 +2131,371 @@ class SimbaSync:
         """
         payload = {
             "input_pairs": [list(t) for t in input_pairs],
-            "hash_message": hash_message
+            "hash_message": hash_message,
         }
         return SimbaRequest(
             method="POST",
             endpoint=Path.USER_ACCOUNT_SIGN.format(uid),
             login=login,
-        ).send_sync(config=config, json_payload=payload)
+        ).send_sync(config=config, json_payload=payload, headers=headers or {})
+
+    def account_address_sign(
+        self,
+        blockchain: str,
+        address: str,
+        input_pairs: List[Tuple[str, Any]],
+        hash_message: Optional[bool] = False,
+        headers: Optional[dict] = None,
+        login: Login = None,
+        config: ConnectionConfig = None,
+    ) -> dict:
+        """
+        POST ``/user/accounts/{account_id}/sign/``
+
+        Sign a message using the specified account.
+
+        :param org: The organisation.
+        :type org: str
+        :param blockchain: The blockchain.
+        :type blockchain: str
+        :param address: The account address.
+        :type address: str
+        :param input_pairs: A list of tuples defining the data type and data to sign.
+        :type input_pairs: List[Tuple(str, Any)]
+
+        :Keyword Arguments:
+            * **headers** (`Optional[dict]`) - additional http headers
+            * **login** (`Optional[Login]`)
+            * **config** (`Optional[ConnectionConfig]`)
+        :return: a Dict with the signed content.
+        :rtype: dict
+        """
+        payload = {
+            "input_pairs": [list(t) for t in input_pairs],
+            "hash_message": hash_message,
+        }
+        return SimbaRequest(
+            method="POST",
+            endpoint=Path.USER_ACCOUNT_ADDRESS_SIGN.format(blockchain, address),
+            login=login,
+        ).send_sync(config=config, json_payload=payload, headers=headers or {})
+
+    def admin_get_accounts(
+        self,
+        alias: Optional[str] = None,
+        network: Optional[str] = None,
+        owner_type: Optional[str] = None,
+        owner_identifier: Optional[str] = None,
+        headers: Optional[dict] = None,
+        login: Login = None,
+        config: ConnectionConfig = None,
+    ) -> List[dict]:
+        """
+        GET ``/admin/accounts/``
+
+        Get the accounts for the current user. Optionally filter on
+        nickname or alias.
+
+        :Keyword Arguments:
+            * **nickname** (`Optional[str]`)
+            * **alias** (`Optional[str]`)
+            * **network** (`Optional[str]`)
+            * **owner_identifier** (`Optional[str]`)
+            * **owner_type** (`Optional[str]`)
+            * **headers** (`Optional[dict]`) additional http headers
+            * **login** (`Optional[Login]`)
+            * **config** (`Optional[ConnectionConfig]`)
+        :return: a list of account objects
+        :rtype: list
+        """
+        params = None
+        if alias or network or owner_type:
+            params = SearchFilter()
+            if owner_type:
+                params.add_filter(
+                    FieldFilter(field="owner_type", op=FilterOp.EQ, value=owner_type)
+                )
+                if owner_identifier:
+                    params.add_filter(
+                        FieldFilter(field="owner_identifier", op=FilterOp.EQ, value=owner_identifier)
+                    )
+            if alias:
+                params.add_filter(
+                    FieldFilter(field="alias", op=FilterOp.EQ, value=alias)
+                )
+            if network:
+                params.add_filter(
+                    FieldFilter(field="networks", op=FilterOp.EQ, value=network)
+                )
+        return SimbaRequest(
+            endpoint=Path.ADMIN_ACCOUNTS,
+            query_params=params.query,
+            login=login,
+        ).retrieve_sync(config=config, headers=headers or {})
+
+    def get_org_accounts(
+        self,
+        org: str,
+        nickname: Optional[str] = None,
+        alias: Optional[str] = None,
+        network: Optional[str] = None,
+        headers: Optional[dict] = None,
+        login: Login = None,
+        config: ConnectionConfig = None,
+    ) -> List[dict]:
+        """
+        GET ``/v2/organisations/{org}/accounts/``
+
+        Get the accounts for the current user. Optionally filter on
+        nickname or alias.
+
+        :param org: The organisation.
+        :type org: str
+
+        :Keyword Arguments:
+            * **nickname** (`Optional[str]`)
+            * **alias** (`Optional[str]`)
+            * **network** (`Optional[str]`)
+            * **headers** (`Optional[dict]`) additional http headers
+            * **login** (`Optional[Login]`)
+            * **config** (`Optional[ConnectionConfig]`)
+        :return: a list of account objects
+        :rtype: list
+        """
+        params = None
+        if nickname or alias or network:
+            params = SearchFilter()
+            if nickname:
+                params.add_filter(
+                    FieldFilter(field="nickname", op=FilterOp.EQ, value=nickname)
+                )
+            if alias:
+                params.add_filter(
+                    FieldFilter(field="alias", op=FilterOp.EQ, value=alias)
+                )
+            if network:
+                params.add_filter(
+                    FieldFilter(field="networks", op=FilterOp.EQ, value=network)
+                )
+        return SimbaRequest(
+            endpoint=Path.ORG_ACCOUNTS.create(org),
+            query_params=params,
+            login=login,
+        ).retrieve_sync(config=config, headers=headers or {})
+
+    def get_org_account(
+        self,
+        org: str,
+        uid: str,
+        headers: Optional[dict] = None,
+        login: Login = None,
+        config: ConnectionConfig = None,
+    ) -> dict:
+        """
+        GET ``/v2/organisations/{org}/accounts/{id}``
+
+        Get the account for the current user with the given id.
+
+        :param org: The organisation.
+        :type org: str
+
+        :Keyword Arguments:
+            * **headers** (`Optional[dict]`) - additional http headers
+            * **login** (`Optional[Login]`)
+            * **config** (`Optional[ConnectionConfig]`)
+        :return: an account object.
+        :rtype: dict
+        """
+        return SimbaRequest(
+            endpoint=Path.ORG_ACCOUNT.format(org, uid),
+            login=login,
+        ).send_sync(config=config, headers=headers or {})
+
+    def create_org_account(
+        self,
+        org: str,
+        network_subtype: str,
+        network: str,
+        nickname: str,
+        alias: str,
+        network_type: Optional[str] = "ethereum",
+        headers: Optional[dict] = None,
+        login: Login = None,
+        config: ConnectionConfig = None,
+    ) -> dict:
+        """
+        POST ``/v2/organisations/{org}/accounts/``
+
+        Create a new account for the current user.
+
+        :param org: The organisation.
+        :type org: str
+        :param network_subtype: The blockchain subtype.
+        :type network_subtype: str
+        :param network: The blockchain name.
+        :type network: str
+        :param nickname: The account nickname.
+        :type nickname: str
+        :param alias: The account alias.
+        :type alias: str
+
+        :Keyword Arguments:
+            * **headers** (`Optional[dict]`) - additional http headers
+            * **login** (`Optional[Login]`)
+            * **config** (`Optional[ConnectionConfig]`)
+        :return: an account object.
+        :rtype: dict
+        """
+        payload = {
+            "network_type": network_type,
+            "network_subtype": network_subtype,
+            "network": network,
+            "nickname": nickname,
+            "alias": alias,
+        }
+        return SimbaRequest(
+            method="POST",
+            endpoint=Path.ORG_ACCOUNTS.create(org),
+            login=login,
+        ).send_sync(config=config, json_payload=payload, headers=headers or {})
+
+    def set_org_account(
+        self,
+        org: str,
+        network_subtype: str,
+        network: str,
+        nickname: str,
+        alias: str,
+        address: str,
+        private_key: str,
+        network_type: Optional[str] = "ethereum",
+        headers: Optional[dict] = None,
+        login: Login = None,
+        config: ConnectionConfig = None,
+    ) -> dict:
+        """
+        POST ``/user/accounts/set/``
+
+        Create a new account for the current user.
+
+        :param org: The organisation.
+        :type org: str
+        :param network_subtype: The blockchain subtype.
+        :type network_subtype: str
+        :param network: The blockchain name.
+        :type network: str
+        :param nickname: The account nickname.
+        :type nickname: str
+        :param alias: The account alias.
+        :type alias: str
+        :param address: The account address.
+        :type address: str
+        :param private_key: The account private key.
+        :type private_key: str
+
+        :Keyword Arguments:
+            * **network_type** (`Optional[str]`)
+            * **headers** (`Optional[dict]`) - additional http headers
+            * **login** (`Optional[Login]`)
+            * **config** (`Optional[ConnectionConfig]`)
+        :return: an account object.
+        :rtype: dict
+        """
+        payload = {
+            "network_type": network_type,
+            "network_subtype": network_subtype,
+            "network": network,
+            "nickname": nickname,
+            "alias": alias,
+            "public_key": address,
+            "private_key": private_key,
+        }
+        return SimbaRequest(
+            method="POST",
+            endpoint=Path.ORG_ACCOUNT_SET.create(org),
+            login=login,
+        ).send_sync(config=config, json_payload=payload, headers=headers or {})
+
+    def org_account_sign(
+        self,
+        org: str,
+        uid: str,
+        input_pairs: List[Tuple[str, Any]],
+        hash_message: Optional[bool] = False,
+        headers: Optional[dict] = None,
+        login: Login = None,
+        config: ConnectionConfig = None,
+    ) -> dict:
+        """
+        POST ``/user/accounts/{account_id}/sign/``
+
+        Sign a message using the specified account.
+
+        :param org: The organisation.
+        :type org: str
+        :param uid: The account id.
+        :type uid: str
+        :param input_pairs: A list of tuples defining the data type and data to sign.
+        :type input_pairs: List[Tuple(str, Any)]
+
+        :Keyword Arguments:
+            * **headers** (`Optional[dict]`) - additional http headers
+            * **login** (`Optional[Login]`)
+            * **config** (`Optional[ConnectionConfig]`)
+        :return: a Dict with the signed content.
+        :rtype: dict
+        """
+        payload = {
+            "input_pairs": [list(t) for t in input_pairs],
+            "hash_message": hash_message,
+        }
+        return SimbaRequest(
+            method="POST",
+            endpoint=Path.ORG_ACCOUNT_SIGN.create(org, uid),
+            login=login,
+        ).send_sync(config=config, json_payload=payload, headers=headers or {})
+
+    def org_account_address_sign(
+        self,
+        org: str,
+        blockchain: str,
+        address: str,
+        input_pairs: List[Tuple[str, Any]],
+        hash_message: Optional[bool] = False,
+        headers: Optional[dict] = None,
+        login: Login = None,
+        config: ConnectionConfig = None,
+    ) -> dict:
+        """
+        POST ``/user/accounts/{account_id}/sign/``
+
+        Sign a message using the specified account.
+
+        :param org: The organisation.
+        :type org: str
+        :param blockchain: The blockchain.
+        :type blockchain: str
+        :param address: The account address.
+        :type address: str
+        :param input_pairs: A list of tuples defining the data type and data to sign.
+        :type input_pairs: List[Tuple(str, Any)]
+
+        :Keyword Arguments:
+            * **headers** (`Optional[dict]`) - additional http headers
+            * **login** (`Optional[Login]`)
+            * **config** (`Optional[ConnectionConfig]`)
+        :return: a Dict with the signed content.
+        :rtype: dict
+        """
+        payload = {
+            "input_pairs": [list(t) for t in input_pairs],
+            "hash_message": hash_message,
+        }
+        return SimbaRequest(
+            method="POST",
+            endpoint=Path.ORG_ACCOUNT_ADDRESS_SIGN.format(org, blockchain, address),
+            login=login,
+        ).send_sync(config=config, json_payload=payload, headers=headers or {})
 
     def subscribe(
         self,
@@ -2259,11 +2662,15 @@ class SimbaSync:
     def add_event_name(
         self,
         event_name: Optional[str] = None,
-        query_args: Optional[SearchFilter] = None
+        query_args: Optional[SearchFilter] = None,
     ) -> Optional[SearchFilter]:
         if event_name:
             if not query_args:
                 query_args = SearchFilter()
-            if not query_args.has_filter_value(field="event_name", op=FilterOp.EQ, value=event_name):
-                query_args.add_filter(FieldFilter(op=FilterOp.EQ, field="event_name", value=event_name))
-        return query_args
\ No newline at end of file
+            if not query_args.has_filter_value(
+                field="event_name", op=FilterOp.EQ, value=event_name
+            ):
+                query_args.add_filter(
+                    FieldFilter(op=FilterOp.EQ, field="event_name", value=event_name)
+                )
+        return query_args
