@@ -27,12 +27,12 @@ from enum import Enum
 from time import sleep
 from typing import Dict, Iterable, Mapping, Optional, Union
 from urllib.parse import urlencode, urlparse, urlunparse
-from libsimba.config import settings
 
 import httpx
 
 from httpx import AsyncHTTPTransport, HTTPTransport
 from libsimba import schemas
+from libsimba.config import settings
 
 
 class Path(str, Enum):
@@ -64,9 +64,16 @@ class Path(str, Enum):
     USER_ACCOUNTS = "/user/accounts/"
     USER_ACCOUNT = "/user/accounts/{}/"
     USER_ACCOUNT_SIGN = "/user/accounts/{}/sign/"
+    USER_ACCOUNT_ADDRESS_SIGN = "/user/accounts/{}/sign/{}/"
     USER_ACCOUNT_SET = "/user/accounts/set/"
     ORGANISATION = "/v2/organisations/{}/"
     ORGANISATIONS = "/v2/organisations/"
+    ORG_ACCOUNTS = "/v2/organisations/{}/accounts/"
+    ADMIN_ACCOUNTS = "/admin/accounts/"
+    ORG_ACCOUNT = "/v2/organisations/{}/accounts/{}/"
+    ORG_ACCOUNT_SIGN = "/v2/organisations/{}/accounts/{}/sign/"
+    ORG_ACCOUNT_ADDRESS_SIGN = "/v2/organisations/{}/accounts/{}/sign/{}/"
+    ORG_ACCOUNT_SET = "/v2/organisations/{}/accounts/set/"
     ORG_APP = "/v2/organisations/{}/applications/{}/"
     ORG_APPS = "/v2/organisations/{}/applications/"
     ORG_TXN = "/v2/organisations/{}/transactions/{}/"
@@ -90,7 +97,9 @@ class Path(str, Enum):
     def create(self, *args) -> str:
         slots = self.value.count("{}")
         if slots != len(args):
-            raise ValueError(f"Incorrect number of args ({len(args)}) supplied to {self.value}")
+            raise ValueError(
+                f"Incorrect number of args ({len(args)}) supplied to {self.value}"
+            )
         return self.value.format(*args)
 
 
@@ -232,14 +241,16 @@ def async_http_client(config: schemas.ConnectionConfig = None) -> httpx.AsyncCli
     :rtype: httpx.AsyncClient
     """
     if not config:
-        config = schemas.ConnectionConfig(timeout=settings().CONNECTION_TIMEOUT, verify=settings().SSL_VERIFY)
+        config = schemas.ConnectionConfig(
+            timeout=settings().CONNECTION_TIMEOUT, verify=settings().SSL_VERIFY
+        )
     transport = RetryTransport(
-        AsyncHTTPTransport(retries=config.connection_retries, verify=config.verify, http2=config.http2),
+        AsyncHTTPTransport(
+            retries=config.connection_retries, verify=config.verify, http2=config.http2
+        ),
         max_attempts=config.max_attempts,
     )
-    return httpx.AsyncClient(
-        timeout=config.timeout, transport=transport
-    )
+    return httpx.AsyncClient(timeout=config.timeout, transport=transport)
 
 
 def http_client(config: schemas.ConnectionConfig = None) -> httpx.Client:
@@ -251,9 +262,13 @@ def http_client(config: schemas.ConnectionConfig = None) -> httpx.Client:
     :rtype: httpx.Client
     """
     if not config:
-        config = schemas.ConnectionConfig(timeout=settings().CONNECTION_TIMEOUT, verify=settings().SSL_VERIFY)
+        config = schemas.ConnectionConfig(
+            timeout=settings().CONNECTION_TIMEOUT, verify=settings().SSL_VERIFY
+        )
     transport = RetryTransport(
-        HTTPTransport(retries=config.connection_retries, verify=config.verify, http2=config.http2),
+        HTTPTransport(
+            retries=config.connection_retries, verify=config.verify, http2=config.http2
+        ),
         max_attempts=config.max_attempts,
     )
     return httpx.Client(timeout=config.timeout, transport=transport)
